==> nsis_3.04.orig.tar.bz2: nsis-3.04-src/Contrib/Makensisw/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by resource.rc
//
#define IDS_LOADSCRIPT                  1
#define IDS_SAVE                        2
#define IDS_EXIT                        3
#define IDS_COPY                        4
#define IDS_FIND                        5
#define IDS_RECOMPILE                   6
#define IDS_SETTINGS                    7
#define IDS_COMPRESSOR                  8
#define IDS_TEST                        9
#define IDS_EDITSCRIPT                  10
#define IDS_BROWSESCR                   11
#define IDS_CLEARLOG                    12
#define IDS_NSISHOME                    13
#define IDS_FORUM                       15
#define IDS_NSISUPDATE                  16
#define IDS_DOCS                        17
#define IDS_SCRIPT                      18
#define IDS_ZLIB                        19
#define IDS_ZLIB_SOLID                  20
#define IDS_BZIP2                       21
#define IDS_BZIP2_SOLID                 22
#define IDS_RECOMPILE_TEST              23
#define IDS_BEST                        24
#define IDS_LZMA                        25
#define IDS_LZMA_SOLID                  26
#define DLG_MAIN                        101
#define IDI_ICON                        102
#define DLG_ABOUT                       103
#define IDM_MENU                        104
#define IDK_ACCEL                       105
#define IDI_ASSOC_NSI                   112
#define IDI_ASSOC_NSH                   113
#define IDB_LOGO                        115
#define DLG_SETTINGS                    116
#define DLG_WNDSPY                      117
#define IDB_TOOLBAR                     122
#define DLG_COMPRESSOR                  124
#define DLG_SYMBOLSET                   125
#define IDB_TOOLBAR16N24                129
#define IDB_TOOLBAR16D24                130
#define IDB_TOOLBAR16H24                131
#define IDB_TOOLBAR24N24                132
#define IDB_TOOLBAR24D24                133
#define IDB_TOOLBAR24H24                134
#define IDB_TOOLBAR32N24                135
#define IDB_TOOLBAR32D24                136
#define IDB_TOOLBAR32H24                137

#define IDC_VERSION                     200
#define IDC_TOOLBAR                     201
#define IDC_LOGWIN                      202
#define IDC_TEST                        203
#define IDC_ABOUTVERSION                220
#define IDC_ABOUTCOPY                   221
#define IDC_ABOUTPORTIONS               222
#define IDC_CONTRIB                     223
#define IDC_NSISVER                     224
#define IDC_OTHERCONTRIB                225
#define IDC_ABOUTHEADER                 226
#define IDC_ABOUTDONATE                 227
#define IDC_RIGHT                       230
#define IDC_LEFT                        231
#define IDC_CLEAR                       232
#define IDC_LOAD                        233
#define IDC_SAVE                        234
#define IDC_DEL                         235
#define IDC_SYMBOLS                     236
#define IDC_SYMBOL                      237
#define IDC_VALUE                       238
#define IDC_COMPRESSOR                  239
#define IDC_NAMES                       240
#define IDC_SPYDRAG                     220
#define IDC_HWND                        221
#define IDC_WNDID                       222
#define IDC_WNDCLASS                    223
#define IDC_WNDUSERDATA                 224
#define IDC_WNDSTYLE                    225
#define IDC_WNDSIZE                     226
#define IDC_WNDINFO                     227
#define IDC_WNDDPI                      228

#define IDM_MRU_FILE                    6000
#define IDM_CMDBASE                     500
#define IDM_BROWSESCR                   500
#define IDM_ABOUT                       501
#define IDM_NSISHOME                    502
#define IDM_FORUM                       503
#define IDM_NSISUPDATE                  404
#define IDM_SELECTALL                   505
#define IDM_DOCS                        506
#define IDM_LOADSCRIPT                  507
#define IDM_EDITSCRIPT                  508
#define IDM_SAVE                        509
#define IDM_COPYALL                     510
#define IDM_COPYSELECTED                511
#define IDM_FIND                        512
#define IDM_CLEARLOG                    513
#define IDM_RECOMPILE                   514
#define IDM_COMPRESSOR                  515
#define IDM_TEST                        516
#define IDM_FILE                        517
#define IDM_EDIT                        518
#define IDM_SCRIPT                      519
#define IDM_TOOLS                       520
#define IDM_HELP                        521
#define IDM_EXIT                        522
#define IDM_CLEAR_MRU_LIST              523
#define IDM_COMPRESSOR_SUBMENU          524
#define IDM_COMPRESSOR_SCRIPT           525
#define IDM_ZLIB                        526
#define IDM_ZLIB_SOLID                  527
#define IDM_BZIP2                       528
#define IDM_BZIP2_SOLID                 529
#define IDM_LZMA                        530
#define IDM_LZMA_SOLID                  531
#define IDM_BEST                        532
#define IDM_RECOMPILE_TEST              533
#define IDM_CANCEL                      534
#define IDM_SETTINGS                    535
#define IDM_WNDSPY                      536
#define IDM_COPY                        537

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        138
#define _APS_NEXT_COMMAND_VALUE         538
#define _APS_NEXT_CONTROL_VALUE         241
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> nsis_3.06.1.orig.tar.bz2: nsis-3.06.1-src/Contrib/Makensisw/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by resource.rc
//
#define IDS_LOADSCRIPT                  1
#define IDS_SAVE                        2
#define IDS_EXIT                        3
#define IDS_COPY                        4
#define IDS_FIND                        5
#define IDS_RECOMPILE                   6
#define IDS_SETTINGS                    7
#define IDS_COMPRESSOR                  8
#define IDS_TEST                        9
#define IDS_EDITSCRIPT                  10
#define IDS_BROWSESCR                   11
#define IDS_CLEARLOG                    12
#define IDS_NSISHOME                    13
#define IDS_FORUM                       15
#define IDS_NSISUPDATE                  16
#define IDS_DOCS                        17
#define IDS_SCRIPT                      18
#define IDS_ZLIB                        19
#define IDS_ZLIB_SOLID                  20
#define IDS_BZIP2                       21
#define IDS_BZIP2_SOLID                 22
#define IDS_RECOMPILE_TEST              23
#define IDS_BEST                        24
#define IDS_LZMA                        25
#define IDS_LZMA_SOLID                  26
#define DLG_MAIN                        101
#define IDI_ICON                        102
#define DLG_ABOUT                       103
#define IDM_MENU                        104
#define IDK_ACCEL                       105
#define IDI_ASSOC_NSI                   112
#define IDI_ASSOC_NSH                   113
#define IDB_LOGO                        115
#define DLG_SETTINGS                    116
#define DLG_WNDSPY                      117
#define IDB_TOOLBAR                     122
#define DLG_COMPRESSOR                  124
#define DLG_SYMBOLSET                   125
#define IDB_TOOLBAR16N24                129
#define IDB_TOOLBAR16D24                130
#define IDB_TOOLBAR16H24                131
#define IDB_TOOLBAR24N24                132
#define IDB_TOOLBAR24D24                133
#define IDB_TOOLBAR24H24                134
#define IDB_TOOLBAR32N24                135
#define IDB_TOOLBAR32D24                136
#define IDB_TOOLBAR32H24                137

#define IDC_VERSION                     200
#define IDC_TOOLBAR                     201
#define IDC_LOGWIN                      202
#define IDC_TEST                        203
#define IDC_ABOUTVERSION                220
#define IDC_ABOUTCOPY                   221
#define IDC_ABOUTPORTIONS               222
#define IDC_CONTRIB                     223
#define IDC_NSISVER                     224
#define IDC_OTHERCONTRIB                225
#define IDC_ABOUTHEADER                 226
#define IDC_ABOUTDONATE                 227
#define IDC_RIGHT                       230
#define IDC_LEFT                        231
#define IDC_CLEAR                       232
#define IDC_LOAD                        233
#define IDC_SAVE                        234
#define IDC_DEL                         235
#define IDC_SYMBOLS                     236
#define IDC_SYMBOL                      237
#define IDC_VALUE                       238
#define IDC_COMPRESSOR                  239
#define IDC_NAMES                       240
#define IDC_SPYDRAG                     220
#define IDC_HWND                        221
#define IDC_WNDID                       222
#define IDC_WNDCLASS                    223
#define IDC_WNDUSERDATA                 224
#define IDC_WNDSTYLE                    225
#define IDC_WNDLOGISIZE                 226
#define IDC_WNDPHYSSIZE                 227
#define IDC_WNDINFO                     229
#define IDC_WNDDPI                      230

#define IDM_MRU_FILE                    6000
#define IDM_CMDBASE                     500
#define IDM_BROWSESCR                   500
#define IDM_ABOUT                       501
#define IDM_NSISHOME                    502
#define IDM_FORUM                       503
#define IDM_NSISUPDATE                  404
#define IDM_SELECTALL                   505
#define IDM_DOCS                        506
#define IDM_LOADSCRIPT                  507
#define IDM_EDITSCRIPT                  508
#define IDM_SAVE                        509
#define IDM_COPYALL                     510
#define IDM_COPYSELECTED                511
#define IDM_FIND                        512
#define IDM_CLEARLOG                    513
#define IDM_RECOMPILE                   514
#define IDM_COMPRESSOR                  515
#define IDM_TEST                        516
#define IDM_FILE                        517
#define IDM_EDIT                        518
#define IDM_SCRIPT                      519
#define IDM_TOOLS                       520
#define IDM_HELP                        521
#define IDM_EXIT                        522
#define IDM_CLEAR_MRU_LIST              523
#define IDM_COMPRESSOR_SUBMENU          524
#define IDM_COMPRESSOR_SCRIPT           525
#define IDM_ZLIB                        526
#define IDM_ZLIB_SOLID                  527
#define IDM_BZIP2                       528
#define IDM_BZIP2_SOLID                 529
#define IDM_LZMA                        530
#define IDM_LZMA_SOLID                  531
#define IDM_BEST                        532
#define IDM_RECOMPILE_TEST              533
#define IDM_CANCEL                      534
#define IDM_SETTINGS                    535
#define IDM_WNDSPY                      536
#define IDM_COPY                        537
#define IDM_UI_SWITCHOWNEDWINDOW        538 // Alt+F6
#define IDM_UI_SWITCHSECTION            539 // F6
#define IDM_GUIDGEN                     540


// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        138
#define _APS_NEXT_COMMAND_VALUE         541
#define _APS_NEXT_CONTROL_VALUE         241
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
